Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1169)

Unified Diff: mandoline/ui/desktop_ui/browser_window.h

Issue 1340983002: Mandoline UI Process: Update namespaces and file names (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebased Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mandoline/ui/aura/window_tree_host_mojo.cc ('k') | mandoline/ui/desktop_ui/browser_window.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mandoline/ui/desktop_ui/browser_window.h
diff --git a/mandoline/ui/desktop_ui/browser_window.h b/mandoline/ui/desktop_ui/browser_window.h
index 79c40ef065035884ffdf49882eead2f768b9439a..c420a639297e2f80daf6d2be7d40fb354958914b 100644
--- a/mandoline/ui/desktop_ui/browser_window.h
+++ b/mandoline/ui/desktop_ui/browser_window.h
@@ -30,7 +30,7 @@ class BrowserManager;
class ProgressView;
class ToolbarView;
-class BrowserWindow : public mojo::ViewTreeDelegate,
+class BrowserWindow : public mus::ViewTreeDelegate,
public mojo::ViewTreeHostClient,
public web_view::mojom::WebViewClient,
public ViewEmbedder,
@@ -53,9 +53,9 @@ class BrowserWindow : public mojo::ViewTreeDelegate,
float DIPSToPixels(float value) const;
- // Overridden from mojo::ViewTreeDelegate:
- void OnEmbed(mojo::View* root) override;
- void OnConnectionLost(mojo::ViewTreeConnection* connection) override;
+ // Overridden from mus::ViewTreeDelegate:
+ void OnEmbed(mus::View* root) override;
+ void OnConnectionLost(mus::ViewTreeConnection* connection) override;
// Overridden from ViewTreeHostClient:
void OnAccelerator(uint32_t id, mojo::EventPtr event) override;
@@ -79,7 +79,7 @@ class BrowserWindow : public mojo::ViewTreeDelegate,
gfx::Size GetPreferredSize(const views::View* view) const override;
void Layout(views::View* host) override;
- void Init(mojo::View* root);
+ void Init(mus::View* root);
void EmbedOmnibox();
mojo::ApplicationImpl* app_;
@@ -89,9 +89,9 @@ class BrowserWindow : public mojo::ViewTreeDelegate,
BrowserManager* manager_;
ToolbarView* toolbar_view_;
ProgressView* progress_bar_;
- mojo::View* root_;
- mojo::View* content_;
- mojo::View* omnibox_view_;
+ mus::View* root_;
+ mus::View* content_;
+ mus::View* omnibox_view_;
mojo::WeakBindingSet<ViewEmbedder> view_embedder_bindings_;
« no previous file with comments | « mandoline/ui/aura/window_tree_host_mojo.cc ('k') | mandoline/ui/desktop_ui/browser_window.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698